"""ClopHfit: Parse plate-reader and fit ClopHensor titrations."""
from pkg_resources import get_distribution  # type: ignore

__version__ = get_distribution("clophfit").version
__enspire_out_dir__ = f"Meas-{__version__}"
__tecan_out_dir__ = f"out-{__version__}"



"""Type definitions used throughout the clophfit package.

It defines the following types:

- ArrayF: a NumPy array with dtype float64.

- ArrayDict: a dictionary where keys are strings and values are NumPy arrays of dtype float64.
"""

from typing import Union  # py3.9 still requires this

import numpy as np
from numpy import typing as npt

ArrayF = npt.NDArray[np.float_]
ArrayDict = dict[str, ArrayF]
Kwargs = dict[str, Union[str, int, float, bool, None]]
